@@ -115,6 +115,7 @@ module IAIConvert
 
   convert_to_py(o) = o
   convert_to_py(o::Tuple) = convert_to_py.(o)
+  convert_to_py(o::Dict) = Dict(k => convert_to_py(v) for (k, v) in o)
 
   function convert_to_py(o::AbstractDataFrame)
     # Can't use pd.DataFrame(dict) to create because it doesn't preserve order
@@ -130,8 +131,22 @@ module IAIConvert
   end
 
   function convert_to_py(o::AbstractCategoricalVector)
+    function get_value(v)
+      # If DataAPI.unwrap is defined, try to use it to unwrap the value to a
+      # non-categorical value
+      @static if isdefined(CategoricalArrays, :DataAPI) &&
+                 isdefined(CategoricalArrays.DataAPI, :unwrap)
+        new_v = CategoricalArrays.DataAPI.unwrap(v)
+        if !(new_v isa CategoricalArrays.CategoricalValue)
+          return new_v
+        end
+      end
+      # Otherwise fallback to Base.get
+      get(v)
+    end
+
+    col = Any[ismissing(x) ? x : get_value(x) for x in o]
     dtype = pd.CategoricalDtype(categories=levels(o), ordered=isordered(o))
-    col = Any[ismissing(x) ? x : get(x) for x in o]
     pd.Series(convert_to_py(col), dtype=dtype)
   end
   function convert_to_py(o::AbstractVector)
