@@ -1,5 +1,7 @@
 import os as _os
 
+from .installation import iai_run_julia_setup
+
 
 def _iai_version_less_than(version):
     jleval = _Main.string("Base.thispatch(v\"", _Main.iai_version, "\")",
@@ -17,39 +19,7 @@ def _requires_iai_version(required_iai_version, function_name, extra=''):
             "installation to use this function.")
 
 
-from .mixeddata import MixedData
-
-
-### BEGIN JULIA INIT
-# Configure julia with options specified in environment variables
-init_kwargs = {}
-
-if 'IAI_DISABLE_COMPILED_MODULES' in _os.environ:  # pragma: no cover
-    init_kwargs['compiled_modules'] = False
-
-if 'IAI_JULIA' in _os.environ:  # pragma: no cover
-    init_kwargs['runtime'] = _os.environ['IAI_JULIA']
-    # Add Julia bindir to path on Windows so that DLLs can be found
-    if _os.name == 'nt':
-        bindir = _os.path.dirname(_os.environ['IAI_JULIA'])
-        _os.environ['PATH'] += _os.pathsep + bindir
-
-if 'IAI_SYSTEM_IMAGE' in _os.environ:  # pragma: no cover
-    init_kwargs['sysimage'] = _os.environ['IAI_SYSTEM_IMAGE']
-
-
-# Load Julia with IAI_DISABLE_INIT to avoid interfering with stdout during load
-_os.environ['IAI_DISABLE_INIT'] = 'True'
-
-# Do custom Julia init if required
-if len(init_kwargs) > 0:  # pragma: no cover
-    from julia import Julia
-    Julia(**init_kwargs)
-
-from julia import Main as _Main
-
-del _os.environ['IAI_DISABLE_INIT']
-### END JULIA INIT
+_Main = iai_run_julia_setup()
 
 
 # Run Julia setup code
@@ -86,7 +56,7 @@ def set_julia_seed(*args):
 
     Examples
     --------
-    >>> set_julia_seed(seed)
+    >>> iai.set_julia_seed(seed)
     """
     return _Random.seed_b(*args)
 
@@ -148,6 +118,7 @@ def _get_learner_type(jl_obj):
 
 
 # Load all subpackages into main namespace
+from .mixeddata import MixedData
 from .iaibase import *
 from .iaitrees import *
 from .optimaltrees import *
