@@ -2,6 +2,7 @@ from .iai import (_IAI, _Main, _requires_iai_version, _iai_version_less_than,
                   _get_learner_type)
 import warnings as _warnings
 import numpy as _np
+import pandas as _pd
 
 
 def split_data(*args, **kwargs):
@@ -622,6 +623,79 @@ class GridSearch(Learner):
                                                    *args, **kwargs)
         return _IAI.show_questionnaire_convert(self._jl_obj, *args, **kwargs)
 
+    def plot(self, type=None):
+        """Plot the grid search results for Optimal Feature Selection learners.
+
+        Returns a
+        `matplotlib.figure.Figure <https://matplotlib.org/stable/api/_as_gen/matplotlib.figure.Figure.html#matplotlib.figure.Figure>`
+        containing the plotted results.
+
+        In a Jupyter Notebook, the plot will be shown automatically. In a
+        terminal, you can show the plot with `grid.plot().show()`.
+
+        Examples
+        --------
+        >>> grid.plot(type)
+
+        Parameters
+        ----------
+        type : str
+            The type of plot to construct, either `"validation"` or
+            `"importance"`. For more information refer to the
+            `Julia documentation for plotting grid search results <https://docs.interpretable.ai/v2.1.0/OptimalFeatureSelection/visualization/#Plotting-Grid-Search-Results-1>`.
+
+        Compatibility
+        -------------
+        Requires IAI version 2.2 or higher.
+        """
+        _requires_iai_version("2.2.0", "plot")
+
+        if _Main.isa(self.get_learner()._jl_obj,
+                     _IAI.OptimalFeatureSelectionLearner):
+            import julia as _julia
+            _OFS = _julia.core.JuliaModuleLoader().load_module(
+                "Main.IAI.OptimalFeatureSelection")
+
+            d = _OFS.get_plot_data(self._jl_obj)
+
+            if type == 'validation':
+                plot_data = _pd.DataFrame({'sparsity': d['sparsity'],
+                                           'score': d['score']})
+                ax = plot_data.plot(x='sparsity', y='score', legend=False)
+                ax.set_xlabel('Sparsity')
+                ax.set_ylabel('Validation Score')
+                ax.set_title('Validation Score against Sparsity')
+                return ax.get_figure()
+
+            elif type == 'importance':
+                import matplotlib.pyplot as plt
+                f = plt.figure()
+                ax = f.add_subplot(111)
+                # ax.pcolormesh(d['sparsity'], d['feature_names'],
+                #               d['importance'])
+
+                plot_data = _pd.DataFrame(d['importance'],
+                                          index=d['feature_names'],
+                                          columns=d['sparsity'])
+                c = ax.pcolor(plot_data)
+                ax.set_yticks(_np.arange(0.5, len(plot_data.index), 1))
+                ax.set_yticklabels(plot_data.index)
+                ax.set_xticks(_np.arange(0.5, len(plot_data.columns), 1))
+                ax.set_xticklabels(plot_data.columns)
+                ax.set_xlabel('Sparsity')
+                ax.set_title('Normalized Variable Importance')
+
+                f.colorbar(c, ax=ax)
+
+                return f
+
+            else:
+                raise ValueError(
+                    '`type` has to be "validation" or "importance"')
+        else:
+            raise TypeError("GridSearch over " + self._lnr_type.__name__ +
+                            " does not support `plot`.")
+
 
 class ROCCurve():
     """Container for ROC curve information.
@@ -719,6 +793,38 @@ class ROCCurve():
         _requires_iai_version("2.1.0", "get_data")
         return _IAI.get_roc_curve_data_convert(self._jl_obj)
 
+    def plot(self):
+        """Plot the ROC curve using `matplotlib`.
+
+        Returns a
+        `matplotlib.figure.Figure <https://matplotlib.org/stable/api/_as_gen/matplotlib.figure.Figure.html#matplotlib.figure.Figure>`
+        containing the ROC curve.
+
+        In a Jupyter Notebook, the plot will be shown automatically. In a
+        terminal, you can show the plot with `curve.plot().show()`.
+
+        Examples
+        --------
+        >>> curve.plot()
+
+        Compatibility
+        -------------
+        Requires IAI version 2.1 or higher.
+        """
+        _requires_iai_version("2.1.0", "plot")
+
+        d = self.get_data()
+        df = _pd.DataFrame({
+            'fpr': [c['fpr'] for c in d['coords']],
+            'tpr': [c['tpr'] for c in d['coords']],
+        })
+
+        ax = df.plot(x='fpr', y='tpr', legend=False)
+        ax.set_xlabel('False Positive Rate')
+        ax.set_ylabel('True Positive Rate')
+        ax.set_title('AUC %.3f' % d['auc'])
+        return ax.get_figure()
+
 
 class SurvivalCurve():
     """Container for survival curve information.
