@@ -720,7 +720,7 @@ class TreePlot(AbstractVisualization):
 
     Examples
     --------
-    >>> TreePlot(lnr, **kwargs)
+    >>> iai.TreePlot(lnr, **kwargs)
 
     Parameters
     ----------
@@ -746,7 +746,7 @@ class Questionnaire(AbstractVisualization):
 
     Examples
     --------
-    >>> Questionnaire(lnr, **kwargs)
+    >>> iai.Questionnaire(lnr, **kwargs)
 
     Parameters
     ----------
@@ -778,13 +778,13 @@ class MultiQuestionnaire(AbstractVisualization):
     `documentation on advanced tree visualization <https://docs.interpretable.ai/v2.1.0/IAI-Python/julia/#Python-Interactive-Visualizations-1>`
     for more information.
 
-    >>> MultiQuestionnaire(questions)
+    >>> iai.MultiQuestionnaire(questions)
 
     Constructs an interactive questionnaire containing the final fitted learner
     from trained grid search as well as the learner found for each parameter
     combination.
 
-    >>> MultiQuestionnaire(grid)
+    >>> iai.MultiQuestionnaire(grid)
 
     Compatibility
     -------------
@@ -815,13 +815,13 @@ class MultiTreePlot(AbstractVisualization):
     `documentation on advanced tree visualization <https://docs.interpretable.ai/v2.1.0/IAI-Python/julia/#Python-Interactive-Visualizations-1>`
     for more information.
 
-    >>> MultiTreePlot(questions)
+    >>> iai.MultiTreePlot(questions)
 
     Constructs an interactive tree visualization containing the final fitted
     learner from trained grid search as well as the learner found for each
     parameter combination.
 
-    >>> MultiTreePlot(grid)
+    >>> iai.MultiTreePlot(grid)
 
     Compatibility
     -------------
