@@ -50,7 +50,7 @@ end
 include("convert.jl")
 
 
-# Add julia methods for HTML output
+# Add julia methods for output
 @eval IAI begin
   function to_html(obj)
     if showable("text/html", obj)
@@ -61,4 +61,17 @@ include("convert.jl")
       return nothing
     end
   end
+  function to_json(obj)
+    io = IOBuffer()
+    try
+      write_json(io, obj; indent=nothing)
+    catch TypeError
+      write_json(io, obj)
+    end
+    String(take!(io))
+  end
+  function from_json(str)
+    io = IOBuffer(str)
+    read_json(io)
+  end
 end
